==> nextcloud-14.0.13.zip: nextcloud/apps/comments/l10n/bg.js <==
OC.L10N.register(
    "comments",
    {
    "Comments" : "Коментари",
    "You commented" : "Вие коментирахте",
    "%1$s commented" : "%1$s коментира",
    "{author} commented" : "{author} коментира",
    "You commented on %1$s" : "Ти коментира за %1$s",
    "You commented on {file}" : "Ти коментира за {file}",
    "%1$s commented on %2$s" : "%1$s коментиран за %2$s",
    "{author} commented on {file}" : "{author} коментира за {file}",
    "<strong>Comments</strong> for files" : "<strong>Коментари</strong> за файлове",
    "You were mentioned on “{file}”, in a comment by a user that has since been deleted" : "Бяхте споменат/а към “{file}”, в коментар от потребител, който вече е изтрит",
    "{user} mentioned you in a comment on “{file}”" : "{user} те спомена в коментар за “{file}”",
    "Edit comment" : "Редактирай коментра",
    "Delete comment" : "Изтрий коментар",
    "New comment …" : "Нов коментар...",
    "Post" : "Публикация",
    "Cancel" : "Отказ",
    "[Deleted user]" : "[Изтрит потребител]",
    "No comments yet, start the conversation!" : "Все още няма коментари, започнете разговор!",
    "More comments …" : "Още коментари...",
    "Save" : "Запазване",
    "Allowed characters {count} of {max}" : "Позволени символи {count} от {max}",
    "Error occurred while updating comment with id {id}" : "Възникна грешка по време на обновяване на коментар с код {id}",
    "Error occurred while posting comment" : "Възникна грешка по време на изпращане на коментар",
    "_%n unread comment_::_%n unread comments_" : ["%n непрочетен коментар","%n непрочетени коментари"],
    "Comment" : "Коментар",
    "You were mentioned on “%s”, in a comment by a user that has since been deleted" : "Бяхте споменат/а на “%s”, в коментар от потребител, който вече е изтрит",
    "%1$s mentioned you in a comment on “%2$s”" : "%1$s те спомена в коментар за “%2$s”"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-15.0.0.zip: nextcloud/apps/comments/l10n/bg.js <==
OC.L10N.register(
    "comments",
    {
    "Edit comment" : "Редактирай коментра",
    "Delete comment" : "Изтрий коментар",
    "New comment …" : "Нов коментар...",
    "Post" : "Публикация",
    "Cancel" : "Отказ",
    "[Deleted user]" : "[Изтрит потребител]",
    "Comments" : "Коментари",
    "No comments yet, start the conversation!" : "Все-още няма коментари, започни разговор!",
    "More comments …" : "Още коментари...",
    "Save" : "Запазване",
    "Allowed characters {count} of {max}" : "Позволени символи {count} от {max}",
    "Error occurred while updating comment with id {id}" : "Възникна грешка по време на обновяване на коментар с код {id}",
    "Error occurred while posting comment" : "Възникна грешка по време на изпращане на коментар",
    "_%n unread comment_::_%n unread comments_" : ["%n непрочетен коментар","%n непрочетени коментари"],
    "Comment" : "Коментар",
    "You commented" : "Вие коментирахте",
    "%1$s commented" : "%1$s коментира",
    "{author} commented" : "{author} коментира",
    "You commented on %1$s" : "Ти коментира за %1$s",
    "You commented on {file}" : "Ти коментира за {file}",
    "%1$s commented on %2$s" : "%1$s коментиран за %2$s",
    "{author} commented on {file}" : "{author} коментира за {file}",
    "<strong>Comments</strong> for files" : "<strong>Коментари</strong> за файлове",
    "You were mentioned on “{file}”, in a comment by a user that has since been deleted" : "Бяхте споменат/а към “{file}”, в коментар от потребител, който вече е изтрит",
    "{user} mentioned you in a comment on “{file}”" : "{user} те спомена в коментар за “{file}”",
    "You were mentioned on “%s”, in a comment by a user that has since been deleted" : "Бяхте споменат/а на “%s”, в коментар от потребител, който вече е изтрит",
    "%1$s mentioned you in a comment on “%2$s”" : "%1$s те спомена в коментар за “%2$s”"
},
"nplurals=2; plural=(n != 1);");
